gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-anastasis] branch master updated: -add more checks


From: gnunet
Subject: [taler-anastasis] branch master updated: -add more checks
Date: Mon, 23 Aug 2021 13:12:01 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository anastasis.

The following commit(s) were added to refs/heads/master by this push:
     new 4aedf96  -add more checks
4aedf96 is described below

commit 4aedf96ba44ffc804749b595a1ad5d4a17d82d77
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Mon Aug 23 13:11:53 2021 +0200

    -add more checks
---
 contrib/gana         |  2 +-
 src/cli/test_iban.sh | 22 +++++++++++++++++-----
 2 files changed, 18 insertions(+), 6 deletions(-)

diff --git a/contrib/gana b/contrib/gana
index efb2a1f..323cb82 160000
--- a/contrib/gana
+++ b/contrib/gana
@@ -1 +1 @@
-Subproject commit efb2a1fd64e17159c56ff3674083837b5a657a64
+Subproject commit 323cb8276408e2c02b59bbe6e10da904538a149d
diff --git a/src/cli/test_iban.sh b/src/cli/test_iban.sh
index 620b2a5..777bcfb 100755
--- a/src/cli/test_iban.sh
+++ b/src/cli/test_iban.sh
@@ -411,13 +411,25 @@ anastasis-reducer -a \
   )" \
   select_challenge < $R2FILE > $R1FILE 2>> test_reducer.err
 
-# FIXME: check $IBAN1 is properly in $R1FILE
-# FIXME: check TESTKUDOS:5 is properly in $R1FILE
-# FIXME: extract wire transfer subject from $R1FILE
+METHOD=`jq -r -e .challenge_feedback.\"$NAME_UUID\".method < $R1FILE`
+if test "$METHOD" != "iban"
+then
+    exit_fail "Expected method to be 'iban', got ${METHOD}"
+fi
+
+ACC=`jq -r -e .challenge_feedback.\"$NAME_UUID\".details.credit_iban < $R1FILE`
+if test "$ACC" != ${IBAN_CREDIT}
+then
+    exit_fail "Expected account to be ${IBAN_CREDIT}, got ${ACC}"
+fi
+
+AMOUNT=`jq -r -e .challenge_feedback.\"$NAME_UUID\".details.challenge_amount < 
$R1FILE`
+NUMBER=`jq -r -e 
.challenge_feedback.\"$NAME_UUID\".details.wire_transfer_subject < $R1FILE`
+SUBJECT="Anastasis ${NUMBER}"
 
 # FIXME-MS: must do wire transfer here!
 
-# bash
+#bash
 
 echo "TEST INCOMPLETE --- BAILING for now"
 
@@ -411,13 +411,25 @@ anastasis-reducer -a \
 
-# FIXME-MS: must do wire transfer here!
+# FIXME-MS: must do wire transfer using $SUBJECT and $AMOUNT here!
 

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]